==> llm-docs-0.1.2.tgz: package/docs/ai_coding_assistant/installation.md <==
---
id: ai_coding_assistant-installation
---
# Installation Guide

This guide explains how to install and configure the BlueflyAI Coding Assistant in your development environment.

## Prerequisites

- Node.js 18.x or later
- Both bfmcp and native_aijs services properly installed and configured
- Administrative access to create configuration directories

## Installation Steps

### 1. Create Configuration Directories

First, create the necessary configuration directories:

```bash
mkdir -p ~/.cursor
mkdir -p ~/.claude
```

### 2. Copy Configuration Files

Copy the configuration files to their respective directories:

```bash
# Copy Cursor integration configuration
cp ./.cursor/cursor_integration.json ~/.cursor/

# Copy Claude integration configuration
cp ./.claude/claude_integration.json ~/.claude/
```

### 3. Install Dependencies

Navigate to the bfmcp directory and install dependencies:

```bash
cd ./bfmcp
npm install
```

Navigate to the native_aijs directory and install dependencies:

```bash
cd ./native_aijs
npm install
```

### 4. Configure Environment Variables

Create or update the .env file in both bfmcp and native_aijs directories:

```bash
# For bfmcp
echo "ENABLE_AI_CODING_ASSISTANT=true" >> ./bfmcp/.env
echo "CURSOR_CONFIG_PATH=~/.cursor/cursor_integration.json" >> ./bfmcp/.env
echo "CLAUDE_CONFIG_PATH=~/.claude/claude_integration.json" >> ./bfmcp/.env

# For native_aijs
echo "ENABLE_AI_CODING_ASSISTANT=true" >> ./native_aijs/.env
echo "CURSOR_CONFIG_PATH=~/.cursor/cursor_integration.json" >> ./native_aijs/.env
echo "CLAUDE_CONFIG_PATH=~/.claude/claude_integration.json" >> ./native_aijs/.env
```

## Configuration Options

### Core Configuration

Both `cursor_integration.json` and `claude_integration.json` contain configuration options for the AI coding assistant. The main sections include:

- `integrations`: Defines connections to bfmcp and native_aijs
- `features`: Configures specific capabilities like codebase understanding and intelligent editing
- `tools`: Defines the tools available to the coding assistant
- `ui`: Configures user interface integrations
- `security`: Sets security and permission controls

### Feature Configuration

To enable or disable specific features, update the corresponding entry in the appropriate configuration file. For example, to disable architecture visualization:

```json
{
  "features": {
    "architectureVisualization": {
      "enabled": false
    }
  }
}
```

## Verification

To verify that the installation was successful, run the following test commands:

```bash
# Test bfmcp integration
cd ./bfmcp
npm run test:ai-coding-assistant

# Test native_aijs integration
cd ./native_aijs
npm run test:ai-coding-assistant
```

## Troubleshooting

### Common Issues

1. **Configuration Files Not Found**
   - Ensure that the configuration files exist at the specified paths
   - Check that the environment variables are correctly set

2. **Services Not Running**
   - Ensure that both bfmcp and native_aijs services are running
   - Check the logs for any error messages

3. **Permission Issues**
   - Ensure that the application has permission to read the configuration files
   - Check that the user running the application has the necessary permissions

### Getting Help

If you encounter issues, check the following resources:

- [GitHub Issues](https://github.com/bluefly/ai-coding-assistant/issues)
- [Community Forum](https://community.bluefly.io/ai-coding-assistant)
- [API Documentation](https://docs.bluefly.io/api/ai-coding-assistant)

## Next Steps

- [Usage Guide](./usage)
- [API Reference](./api-reference)
- [Examples](./examples)

==> llm-docs-0.1.4.tgz: package/docs/ai_coding_assistant/installation.md <==
---
id: ai_coding_assistant-installation
---
# Installation Guide

This guide explains how to install and configure the LLM PlatformAI Coding Assistant in your development environment.

## Prerequisites

- Node.js 18.x or later
- Both llm-mcp and native_aijs services properly installed and configured
- Administrative access to create configuration directories

## Installation Steps

### 1. Create Configuration Directories

First, create the necessary configuration directories:

```bash
mkdir -p ~/.cursor
mkdir -p ~/.claude
```

### 2. Copy Configuration Files

Copy the configuration files to their respective directories:

```bash
# Copy Cursor integration configuration
cp ./.cursor/cursor_integration.json ~/.cursor/

# Copy Claude integration configuration
cp ./.claude/claude_integration.json ~/.claude/
```

### 3. Install Dependencies

Navigate to the llm-mcp directory and install dependencies:

```bash
cd ./llm-mcp
npm install
```

Navigate to the native_aijs directory and install dependencies:

```bash
cd ./native_aijs
npm install
```

### 4. Configure Environment Variables

Create or update the .env file in both llm-mcp and native_aijs directories:

```bash
# For llm-mcp
echo "ENABLE_AI_CODING_ASSISTANT=true" >> ./llm-mcp/.env
echo "CURSOR_CONFIG_PATH=~/.cursor/cursor_integration.json" >> ./llm-mcp/.env
echo "CLAUDE_CONFIG_PATH=~/.claude/claude_integration.json" >> ./llm-mcp/.env

# For native_aijs
echo "ENABLE_AI_CODING_ASSISTANT=true" >> ./native_aijs/.env
echo "CURSOR_CONFIG_PATH=~/.cursor/cursor_integration.json" >> ./native_aijs/.env
echo "CLAUDE_CONFIG_PATH=~/.claude/claude_integration.json" >> ./native_aijs/.env
```

## Configuration Options

### Core Configuration

Both `cursor_integration.json` and `claude_integration.json` contain configuration options for the AI coding assistant. The main sections include:

- `integrations`: Defines connections to llm-mcp and native_aijs
- `features`: Configures specific capabilities like codebase understanding and intelligent editing
- `tools`: Defines the tools available to the coding assistant
- `ui`: Configures user interface integrations
- `security`: Sets security and permission controls

### Feature Configuration

To enable or disable specific features, update the corresponding entry in the appropriate configuration file. For example, to disable architecture visualization:

```json
{
  "features": {
    "architectureVisualization": {
      "enabled": false
    }
  }
}
```

## Verification

To verify that the installation was successful, run the following test commands:

```bash
# Test llm-mcp integration
cd ./llm-mcp
npm run test:ai-coding-assistant

# Test native_aijs integration
cd ./native_aijs
npm run test:ai-coding-assistant
```

## Troubleshooting

### Common Issues

1. **Configuration Files Not Found**
   - Ensure that the configuration files exist at the specified paths
   - Check that the environment variables are correctly set

2. **Services Not Running**
   - Ensure that both llm-mcp and native_aijs services are running
   - Check the logs for any error messages

3. **Permission Issues**
   - Ensure that the application has permission to read the configuration files
   - Check that the user running the application has the necessary permissions

### Getting Help

If you encounter issues, check the following resources:

- [GitHub Issues](https://github.com/bluefly/ai-coding-assistant/issues)
- [Community Forum](https://community.bluefly.io/ai-coding-assistant)
- [API Documentation](https://docs.bluefly.io/api/ai-coding-assistant)

## Next Steps

- [Usage Guide](./usage)
- [API Reference](./api-reference)
- [Examples](./examples)
